@@ -40,6 +40,7 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFIGURE_LDFLAGS': '-L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib '
                       '-Wl,-R/usr/pkg/lib -L/usr/X11R7/lib '
                       '-Wl,-R/usr/X11R7/lib',
+ 'CONFIGURE_LDFLAGS_NODIST': '',
  'CONFIG_ARGS': "'--enable-shared' '--with-openssl=/usr' '--with-system-ffi' "
                 "'--with-threads' '--without-ensurepip' '--without-pymalloc' "
                 "'--prefix=/usr/pkg' '--build=armv7--netbsdelf-eabihf' "
@@ -55,8 +56,8 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFINCLUDEDIR': '/usr/pkg/include',
  'CONFINCLUDEPY': '/usr/pkg/include/python3.7',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/mnt/earmv7hf/pkgsrc/lang/python37/work.earmv7hf/Python-3.7.1/coverage.info',
- 'COVERAGE_REPORT': '/mnt/earmv7hf/pkgsrc/lang/python37/work.earmv7hf/Python-3.7.1/lcov-report',
+ 'COVERAGE_INFO': '/mnt/earmv7hf/pkgsrc/lang/python37/work.earmv7hf/Python-3.7.2/coverage.info',
+ 'COVERAGE_REPORT': '/mnt/earmv7hf/pkgsrc/lang/python37/work.earmv7hf/Python-3.7.2/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
  'CPPFLAGS': '-I. -I./Include -I/usr/include -I/usr/pkg/include -I/usr/include '
@@ -518,6 +519,7 @@ build_time_vars = {'ABIFLAGS': '',
             '-L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib -L/usr/lib -Wl,-R/usr/lib '
             '-L/usr/pkg/lib -Wl,-R/usr/pkg/lib -L/usr/X11R7/lib '
             '-Wl,-R/usr/X11R7/lib',
+ 'LDFLAGS_NODIST': '',
  'LDLAST': '',
  'LDLIBRARY': 'libpython3.7.so',
  'LDLIBRARYDIR': '',
@@ -617,9 +619,21 @@ build_time_vars = {'ABIFLAGS': '',
  'PYTHONFRAMEWORKPREFIX': '',
  'PYTHONPATH': '',
  'PYTHON_FOR_BUILD': './python -E',
- 'PYTHON_FOR_REGEN': 'python3.7',
+ 'PYTHON_FOR_REGEN': 'python3',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
+ 'PY_BUILTIN_MODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O2 '
+                             '-D_FORTIFY_SOURCE=2 -I/usr/include '
+                             '-I/usr/pkg/include -O2 -D_FORTIFY_SOURCE=2 '
+                             '-I/usr/include -I/usr/pkg/include -O2 '
+                             '-D_FORTIFY_SOURCE=2 -I/usr/include '
+                             '-I/usr/pkg/include -std=gnu99 -Wextra '
+                             '-Wno-unused-result -Wno-unused-parameter '
+                             '-Wno-missing-field-initializers '
+                             '-Werror=implicit-function-declaration -I. '
+                             '-I./Include -I/usr/include -I/usr/pkg/include '
+                             '-I/usr/include -I/usr/pkg/include -fPIC '
+                             '-DPy_BUILD_CORE_BUILTIN',
  'PY_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O2 '
               '-D_FORTIFY_SOURCE=2 -I/usr/include -I/usr/pkg/include -O2 '
               '-D_FORTIFY_SOURCE=2 -I/usr/include -I/usr/pkg/include -O2 '
@@ -637,6 +651,10 @@ build_time_vars = {'ABIFLAGS': '',
                    '-Werror=implicit-function-declaration -I. -I./Include '
                    '-I/usr/include -I/usr/pkg/include -I/usr/include '
                    '-I/usr/pkg/include -fPIC -DPy_BUILD_CORE',
+ 'PY_CORE_LDFLAGS': '-L. -L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib '
+                    '-Wl,-R/usr/pkg/lib -L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib '
+                    '-L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib '
+                    '-Wl,-R/usr/pkg/lib -L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib',
  'PY_CPPFLAGS': '-I. -I./Include -I/usr/include -I/usr/pkg/include '
                 '-I/usr/include -I/usr/pkg/include',
  'PY_FORMAT_SIZE_T': '"z"',
@@ -644,6 +662,7 @@ build_time_vars = {'ABIFLAGS': '',
                '-Wl,-R/usr/pkg/lib -L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib '
                '-L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib -Wl,-R/usr/pkg/lib '
                '-L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib',
+ 'PY_LDFLAGS_NODIST': '',
  'PY_SSL_DEFAULT_CIPHERS': 1,
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
  'PY_STDMODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O2 '
@@ -663,7 +682,7 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/mnt/earmv7hf/pkgsrc/lang/python37/work.earmv7hf/Python-3.7.1',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/mnt/earmv7hf/pkgsrc/lang/python37/work.earmv7hf/Python-3.7.2',
  'SCRIPTDIR': '/usr/pkg/lib',
  'SETPGRP_HAVE_ARG': 1,
  'SGI_ABI': '@SGI_ABI@',
@@ -705,10 +724,10 @@ build_time_vars = {'ABIFLAGS': '',
  'TCLTK_LIBS': '',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/mnt/earmv7hf/pkgsrc/lang/python37/work.earmv7hf/Python-3.7.1 '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/mnt/earmv7hf/pkgsrc/lang/python37/work.earmv7hf/Python-3.7.2 '
                './python',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/mnt/earmv7hf/pkgsrc/lang/python37/work.earmv7hf/Python-3.7.1 '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/mnt/earmv7hf/pkgsrc/lang/python37/work.earmv7hf/Python-3.7.2 '
                './python ./Tools/scripts/run_tests.py',
  'TESTTIMEOUT': 1200,
  'TIMEMODULE_LIB': 0,
@@ -716,7 +735,7 @@ build_time_vars = {'ABIFLAGS': '',
  'TM_IN_SYS_TIME': 0,
  'UNICODE_DEPS': '\\',
  'UNIVERSALSDK': '',
- 'UPDATE_FILE': 'python3.7 ./Tools/scripts/update_file.py',
+ 'UPDATE_FILE': 'python3 ./Tools/scripts/update_file.py',
  'USE_COMPUTED_GOTOS': 0,
  'VERSION': '3.7',
  'WINDOW_HAS_FLAGS': 0,
@@ -729,8 +748,8 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/mnt/earmv7hf/pkgsrc/lang/python37/work.earmv7hf/Python-3.7.1',
- 'abs_srcdir': '/mnt/earmv7hf/pkgsrc/lang/python37/work.earmv7hf/Python-3.7.1',
+ 'abs_builddir': '/mnt/earmv7hf/pkgsrc/lang/python37/work.earmv7hf/Python-3.7.2',
+ 'abs_srcdir': '/mnt/earmv7hf/pkgsrc/lang/python37/work.earmv7hf/Python-3.7.2',
  'datarootdir': '/usr/pkg/share',
  'exec_prefix': '/usr/pkg',
  'prefix': '/usr/pkg',
